package com.xxl.job.executor.ads.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.xxl.job.executor.ads.entity.AiKuaishouStrategy;
import com.xxl.job.executor.ads.service.IAiKuaishouStrategyService;
import com.xxl.job.executor.entity.vo.Result;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;
import java.util.Arrays;

 /**
 * 智能投放策略信息
 * @author jeecg-boot
 * @date   2020-12-10
 * @version V1.0
 */
@Slf4j
@RestController
@RequestMapping("/ctop/aiKuaishouStrategy")
public class AiKuaishouStrategyController {
	@Autowired
	private IAiKuaishouStrategyService aiKuaishouStrategyService;

	/**
	  * 分页列表查询
	 * @param aiKuaishouStrategy
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	@GetMapping(value = "/list")
	public Result<IPage<AiKuaishouStrategy>> queryPageList(AiKuaishouStrategy aiKuaishouStrategy,
                                                           @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
                                                           @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
                                                           HttpServletRequest req) {
		Result<IPage<AiKuaishouStrategy>> result = new Result<>();
		QueryWrapper<AiKuaishouStrategy> queryWrapper = new QueryWrapper<>();
		Page<AiKuaishouStrategy> page = new Page<>(pageNo, pageSize);
		IPage<AiKuaishouStrategy> pageList = aiKuaishouStrategyService.page(page, queryWrapper);
		result.setSuccess(true);
		result.setResult(pageList);
		return result;
	}

	/**
	  *   添加
	 * @param aiKuaishouStrategy
	 * @return
	 */
	@PostMapping(value = "/add")
	public Result<AiKuaishouStrategy> add(@RequestBody AiKuaishouStrategy aiKuaishouStrategy) {
		Result<AiKuaishouStrategy> result = new Result<>();
		try {
			aiKuaishouStrategyService.save(aiKuaishouStrategy);
			result.success("添加成功！");
		} catch (Exception e) {
			log.error(e.getMessage(),e);
			result.error500("操作失败");
		}
		return result;
	}

	/**
	  *  编辑
	 * @param aiKuaishouStrategy
	 * @return
	 */
	@PutMapping(value = "/edit")
	public Result<AiKuaishouStrategy> edit(@RequestBody AiKuaishouStrategy aiKuaishouStrategy) {
		Result<AiKuaishouStrategy> result = new Result<AiKuaishouStrategy>();
		AiKuaishouStrategy aiKuaishouStrategyEntity = aiKuaishouStrategyService.getById(aiKuaishouStrategy.getId());
		if(aiKuaishouStrategyEntity==null) {
			result.error500("未找到对应实体");
		}else {
			boolean ok = aiKuaishouStrategyService.updateById(aiKuaishouStrategy);
			if(ok) {
				result.success("修改成功!");
			}
		}

		return result;
	}

	/**
	  *   通过id删除
	 * @param id
	 * @return
	 */
	@DeleteMapping(value = "/delete")
	public Result<?> delete(@RequestParam(name="id",required=true) String id) {
		try {
			aiKuaishouStrategyService.removeById(id);
		} catch (Exception e) {
			log.error("删除失败",e.getMessage());
			return Result.error("删除失败!");
		}
		return Result.ok("删除成功!");
	}

	/**
	  *  批量删除
	 * @param ids
	 * @return
	 */
	@DeleteMapping(value = "/deleteBatch")
	public Result<AiKuaishouStrategy> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		Result<AiKuaishouStrategy> result = new Result<>();
		if(ids==null || "".equals(ids.trim())) {
			result.error500("参数不识别！");
		}else {
			this.aiKuaishouStrategyService.removeByIds(Arrays.asList(ids.split(",")));
			result.success("删除成功!");
		}
		return result;
	}

	/**
	  * 通过id查询
	 * @param id
	 * @return
	 */
	@GetMapping(value = "/queryById")
	public Result<AiKuaishouStrategy> queryById(@RequestParam(name="id",required=true) String id) {
		Result<AiKuaishouStrategy> result = new Result<>();
		AiKuaishouStrategy aiKuaishouStrategy = aiKuaishouStrategyService.getById(id);
		if(aiKuaishouStrategy==null) {
			result.error500("未找到对应实体");
		}else {
			result.setResult(aiKuaishouStrategy);
			result.setSuccess(true);
		}
		return result;
	}
}
